#
# spec file for package ghc-jira-wiki-markup
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name jira-wiki-markup
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.5.1
Release:        2.5
Summary:        Handle Jira wiki markup
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-parsec-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
Parse jira wiki text into an abstract syntax tree for easy transformation to
other formats.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/%{pkg_name}

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Mon Dec 25 2023 Peter Simons <psimons@suse.com>
- Update jira-wiki-markup to version 1.5.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Mar 13 2023 Peter Simons <psimons@suse.com>
- Update jira-wiki-markup to version 1.5.1.
  1.5.1
  - ----
  Released 2023-03-13.
  * Parser: Disallow image paths that start with a space.
* Wed Jan 11 2023 Peter Simons <psimons@suse.com>
- Update jira-wiki-markup to version 1.5.0.
  1.5.0
  - ----
  Released 2023-01-11.
  * Relaxed upper bounds for mtl, allow mtl 2.3.
  * Fixed handling of character sequences that would be interpreted
    as icons if they weren't followed by an alphanumeric character.
    See also [pandoc issue #8511][].
  [pandoc issue #8511]: https://github.com/jgm/pandoc/issues/8511
* Fri Jun  3 2022 Peter Simons <psimons@suse.com>
- Update jira-wiki-markup to version 1.4.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed May 26 2021 psimons@suse.com
- Update jira-wiki-markup to version 1.4.0.
  1.4.0
  - ----
  Released 2021-05-25.
  * Allow quoted image parameters.
  * Added support for "smart links".
  * **API Change**: Add new constructors `SmartCard` and `SmartLink` to
    Text.Jira.Markup.LinkType.
* Mon May 24 2021 psimons@suse.com
- Update jira-wiki-markup to version 1.3.5.
  1.3.5
  - ----
  Released 2021-05-24.
  * Allow spaces and most unicode characters in attachment links.
  * No longer require a newline character after `{noformat}`.
  * Only allow URI path segment characters in bare links.
  * The `file:` schema is no longer allowed in bare links; these
    rarely make sense.
* Sun Mar 14 2021 psimons@suse.com
- Update jira-wiki-markup to version 1.3.4.
  1.3.4
  - ----
  Released 2021-03-13.
  * Fixed parsing of autolinks (i.e., of bare URLs in the text).
    Previously an autolink would take up the rest of a line, as
    spaces were allowed characters in these items.
  * Emoji character sequences no longer cause parsing failures. This
    was due to missing backtracking when emoji parsing fails.
  * Block quotes are only rendered as `bq.` if they do not contain a
    linebreak.
* Sat Feb 13 2021 psimons@suse.com
- Update jira-wiki-markup to version 1.3.3.
  1.3.3
  - ----
  Released 2021-02-12.
  * Modified the Doc parser to skip leading blank lines. This fixes
    parsing of documents which start with multiple blank lines.
  * Prevent URLs within link aliases to be treated as autolinks.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Wed Jul  8 2020 psimons@suse.com
- Update jira-wiki-markup to version 1.3.2.
  * Braces are now always escaped when printing; Jira treats braces
    specially, regardless of context.
  * Added support for links to anchors.
  * Styled text may not wrap across multiple lines; linebreaks in
    marked-up text are now forbidden.
  * Module Text.Jira.Parser.Core: new function `many1Till` which
    behaves like `manyTill`, but requires at least on element to be
    parsed.
  * Ensured the package works with GHC 8.10.
  * Support was added for additional syntax constructs:
  - citation markup (`??citation??`),
  - links to attachments (`[title^attachment.ext]`), and
  - user links (`[~username]`).
  * Changes to module `Text.Jira.Markup`:
  * A new data type `LinkType` is exported from the module.
  * Changes to type `Inline`:
  - a new constructor `Citation` has been added;
  - the `Link` constructor now takes an additional
  parameter of type `LinkType`.
  * Fixed rendering of image attributes: image attributes are
    separated by commas instead of pipes; the latter are used in
    block parameters.
  * Fixed parsing of blockquotes which are not preceeded by blank
    lines.
  * Ensure parsing of single-line blockquotes is possible even if
    there is no space between `bq.` marker and contents.
  * Fixed parsing of colors: parsing no longer fails for hexcolors
    which contain non-decimal digits.
  * Changes to module `Text.Jira.Parser.Shared`:
  - New parsing function `colorName` which parses a color
  descriptor, i.e. either a name or a hexcolor.
  * Added check that a closing markup char is not preceeded by a
    whitespace character. Previously, plain text was still
    incorrectly treated as markup. E.g., the dashes in `-> step ->`
    used to be interpreted as delimiters marking deleted text.
  * Allows empty table cells; table parsing failed if one of the
    cells did not contain any content.
  * Changes to module `Text.Jira.Parser.Core`:
  - A field `stateLastSpcPos` was added to data type
  `ParserState` to keep track of spaces.
  - Function `updateLastSpcPos` was added to update the
  aforementioned field.
  - Function `afterSpace` was added to test the field.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed May  6 2020 psimons@suse.com
- Update jira-wiki-markup to version 1.1.4.
  * Fixed parsing of image parameters. Thumbnails and images with
    parameters were previously not recognized as images.
  * Fixed table detection in endOfParagraph parser: Tables were
    expected to have a space between the leading pipe(s) and the
    cell content. Lines like `||Name|` were erroneously not
    recognized as the beginning of a new block.
  * Don't escape colon/semicolon unless necessary: it is necessary
    to escape colons or semicolons only if they could otherwise
    become part of a smiley.
  * Colon `:` and semicolon `;` are now parsed as special
    characters, since they can be the first characters of an emoji.
  * Fixed parsing of words which contain non-special symbol
    characters: word boundaries were not set correctly if a word
    contained a dot `.` or similar chars.
  * Fixed incorrect emphasis parsing: digits were erroneously allows
    as the first characters after closing emphasis characters.
  * Lists are now allowed to be indented; i.e., lists are still
    recognized if list markers are preceded by spaces.
  * Support for colored inlines has been added.
  * New constructor `ColorInline` for type `Inline` (API change).
* Thu Dec 26 2019 psimons@suse.com
- Add jira-wiki-markup at version 1.0.0.
